Vanlige knapper

Grunnleggende knapper | IF

Nedenfor finner du en kort beskrivelse av hver knapp/funksjon.

| Fet tekst.
| Kursiv tekst.
| Understreket tekst.
| Gjennomstreket tekst.
| Rett venstremarg.
| Sentrer.
| Rett høyremarg.
| Rette marger.
| Punktliste.
| Nummerliste
| Reduser innrykk.
| Øk innrykk.
| Angre seneste endring.
| Gjør om seneste endring.
| Lage/Redigere lenke, lær mer om denne funksjonen i kapittelet Lage/Redigere lenke.
| Ta bort lenker fra markerte lenker.
| Lage/Redigere anker, lær mer om denne funksjonen i kapittelet Lage/Redigere anker.
| Lage/Redigere bilde, lær mer om denne funksjonen i kapittelet Lage/Redigere bilde.
| Rense/Ordne koden. Denne funksjonen tar bort unødvendig formatering. Bør anvendes når man f.eks. kopierer tekst fra Office-program.
| Viser denne hjelp.
| Åpner en HTML-kodeeditor.
| Lager en ny tabell (2x2).
| Lager en rad ovenfor den nåværende raden.
| Lager en rad under den nåværende raden.
| Tar bort en rad.
| Lager en kolonne før den nåværende kolonnen.
| Lager en kolonne etter den nåværende kolonnen.
| Tar bort en kolonne.
| Lager en horisontal linje.
| Tar bort formatering fra markert område.
| Lager nedsenket tekst.
| Lager opphøyd tekst.

Gå til: Innholdsoversikt | Toppen